pub enum Error {
InvalidCodepoint(u32),
GaveUp,
}Expand description
An error that can occur during construction of a trie.
Variants
InvalidCodepoint(u32)
This error is returned when an invalid codepoint is given to
TrieSetOwned::from_codepoints. An invalid codepoint is a u32 that
is greater than 0x10FFFF.
GaveUp
This error is returned when a set of Unicode codepoints could not be sufficiently compressed into the trie provided by this crate. There is no work-around for this error at this time.